@@ -124,9 +124,22 @@ gconf_editor_window_copy_key_name (gpointer callback_data, guint action, GtkWidg
 {
 	GConfEditorWindow *window = GCONF_EDITOR_WINDOW (callback_data);
 	char *path;
+	gchar *key;
 	GtkTreeIter iter;
 	GtkTreeIter child_iter;
 	
+	if (gtk_tree_selection_get_selected (gtk_tree_view_get_selection
+					     (GTK_TREE_VIEW (window->list_view)),
+					     NULL, &iter) == TRUE) {
+		gtk_tree_model_get (window->sorted_list_model, &iter,
+                	            GCONF_LIST_MODEL_KEY_PATH_COLUMN, &key,
+                        	    -1);
+		gtk_clipboard_set_text (gtk_clipboard_get
+					(GDK_SELECTION_CLIPBOARD), key, -1);
+		g_free (key);
+		return;
+	}
+		
 	gtk_tree_selection_get_selected (gtk_tree_view_get_selection (GTK_TREE_VIEW (window->tree_view)), NULL, &iter);
 
 	gtk_tree_model_sort_convert_iter_to_child_iter (GTK_TREE_MODEL_SORT (window->sorted_tree_model), &child_iter, &iter);
@@ -230,7 +243,7 @@ gconf_editor_window_about_window (gpointer callback_data, guint action, GtkWidge
 				  "<span size=\"small\">%s</span>\n",
 				  _("GConf-Editor"),
 				  _("An editor for the GConf configuration system."),
-				  _("Copyright (C) Anders Carlsson 2001, 2002"));
+				  "Copyright \xc2\xa9 2001-2004 Anders Carlsson");
 	gtk_label_set_markup (GTK_LABEL (label), markup);
 	g_free (markup);
 	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
@@ -645,7 +658,7 @@ gconf_editor_window_selection_changed (GtkTreeSelection *selection, GConfEditorW
 	if (selection == NULL)
 		gtk_window_set_title (GTK_WINDOW (window), _("GConf editor"));
 	else {
-		gchar *name, *title, *path;
+	  	gchar *name, *title, *path, *escape_path;
 		GtkTreeIter child_iter;
 
 		if (!gtk_tree_selection_get_selected (selection, NULL, &iter)) {
@@ -668,8 +681,11 @@ gconf_editor_window_selection_changed (GtkTreeSelection *selection, GConfEditorW
 		gtk_statusbar_pop (GTK_STATUSBAR (window->statusbar), 0);
 		gtk_statusbar_push (GTK_STATUSBAR (window->statusbar), 0, path);
 
-		gconf_list_model_set_root_path (GCONF_LIST_MODEL (window->list_model), path);
+		escape_path = gconf_tree_model_get_gconf_escape_path (path);
+		
+		gconf_list_model_set_root_path (GCONF_LIST_MODEL (window->list_model), escape_path);
 
+		g_free (escape_path);
 		g_free (path);
 
 	}
@@ -873,7 +889,10 @@ gconf_editor_window_update_list_selection (GtkTreeSelection *selection, GConfEdi
 		gtk_label_set_text (GTK_LABEL (window->owner_label), _("(None)"));
 
 	}
-		
+
+	gtk_statusbar_pop (GTK_STATUSBAR (window->statusbar), 0);
+	gtk_statusbar_push (GTK_STATUSBAR (window->statusbar), 0, path);
+
 	g_free (path);
 }
 
