@@ -692,6 +692,9 @@ gconf_key_editor_set_value (GConfKeyEditor *editor, GConfValue *value)
 				case GCONF_VALUE_INT:
 					gtk_option_menu_set_history (GTK_OPTION_MENU (editor->list_type_menu), EDIT_INTEGER);
 					break;
+				case GCONF_VALUE_FLOAT:
+					gtk_option_menu_set_history (GTK_OPTION_MENU (editor->list_type_menu), EDIT_FLOAT);
+					break;
 				case GCONF_VALUE_STRING:
 					gtk_option_menu_set_history (GTK_OPTION_MENU (editor->list_type_menu), EDIT_STRING);
 					break;
